@@ -12,8 +12,6 @@ from .tools import abort
 from .tools import ensure_project_name
 from .tools import print_prod_env
 
-APT_CACHER_CONTAINER_NAME = "apt-cacher"
-
 
 @cli.group(cls=AliasedGroup)
 @pass_config
@@ -71,10 +69,13 @@ def execute(config, machine, args):
 @click.pass_context
 def do_kill(ctx, config, machines, brutal, profile):
     ensure_project_name(config)
+    if config.devmode:
+        click.secho("Being brutal because in devmode", fg="red")
+        brutal = True
     if config.use_docker:
         from .lib_control_with_docker import do_kill as lib_do_kill
 
-        lib_do_kill(ctx, config, machines, brutal=False, profile=profile)
+        lib_do_kill(ctx, config, machines, brutal=brutal, profile=profile)
 
 
 @docker.command()
@@ -281,228 +282,6 @@ def attach(ctx, config, machine):
     lib_attach(ctx, config, machine)
 
 
-def delete_gpg_files():
-    start_apt_cacher()
-    cmd = "find /var/cache/apt-cacher-ng/ -type f \( -name '*InRelease' -o -name '*Release.gpg' \)"
-    subprocess.run(
-        ["docker", "exec", APT_CACHER_CONTAINER_NAME, "sh", "-c", cmd]
-    )
-
-
-def start_apt_cacher():
-    container_name = APT_CACHER_CONTAINER_NAME
-    image_name = "sameersbn/apt-cacher-ng:latest"
-    network = "aptcache-net"  # necessary so name resolution works
-    port_mapping = "3142:3142"
-
-    def setup_options():
-        ancg_conf = (
-            subprocess.run(
-                [
-                    "docker",
-                    "exec",
-                    container_name,
-                    "cat",
-                    "/etc/apt-cacher-ng/acng.conf",
-                ],
-                capture_output=True,
-                text=True,
-                check=True,
-            )
-            .stdout.strip()
-            .splitlines()
-        )
-        ancg_conf = [
-            line.strip()
-            for line in ancg_conf
-            if line.strip() and not line.startswith("#")
-        ]
-        print("\n".join(ancg_conf))
-        if not any("ExThreshold: 0" in line for line in ancg_conf) or not any(
-            "DlMaxRetries: 5" in line for line in ancg_conf
-        ):
-            for option in [
-                "ExThreshold: 0",
-                "PassThroughPattern: .*Release|.*Packages|.*Sources",
-                "DlMaxRetries: 5",
-            ]:
-                click.secho(f"Adding option: {option}", fg="yellow")
-                subprocess.run(
-                    [
-                        "docker",
-                        "exec",
-                        container_name,
-                        "sh",
-                        "-c",
-                        f"echo '{option}' >> /etc/apt-cacher-ng/acng.conf",
-                    ]
-                )
-            subprocess.run(["docker", "restart", container_name])
-
-    # Check if container is already running
-    result = subprocess.run(
-        ["docker", "ps", "-q", "-f", f"name={container_name}"],
-        capture_output=True,
-        text=True,
-    )
-    if result.stdout.strip():
-        setup_options()
-        click.secho(f"Container '{container_name}' is already running.")
-        return
-
-    create_network(network)
-
-    # If not running, start it
-    result = subprocess.run(
-        ["docker", "ps", "-q", "-a", "-f", f"name={container_name}"],
-        capture_output=True,
-        text=True,
-    ).stdout.strip()
-    if result:
-        cmd = [
-            "docker",
-            "start",
-            result,
-        ]
-    else:
-        cmd = [
-            "docker",
-            "run",
-            "-d",
-            "--name",
-            container_name,
-            "--network",
-            network,
-            "-p",
-            port_mapping,
-            image_name,
-        ]
-    click.secho(f"Starting container '{container_name}'...", fg="blue")
-
-    try:
-        subprocess.run(cmd, check=True)
-        click.secho(
-            f"Container '{container_name}' started on port 3142.", fg="green"
-        )
-    except subprocess.CalledProcessError as e:
-        abort(str(e))
-
-    setup_options()
-
-
-def create_network(name="aptcache-net"):
-    # Check if the network already exists
-    result = subprocess.run(
-        [
-            "docker",
-            "network",
-            "ls",
-            "--filter",
-            f"name=^{name}$",
-            "--format",
-            "{{.Name}}",
-        ],
-        capture_output=True,
-        text=True,
-    )
-
-    if name in result.stdout.splitlines():
-        click.secho(f"Network '{name}' already exists.", fg="green")
-        return
-
-    # Create the network
-    click.secho(f"Creating Docker network '{name}'...", fg="yellow")
-    try:
-        subprocess.run(["docker", "network", "create", name], check=True)
-        click.secho(f"Network '{name}' created successfully.", fg="green")
-    except subprocess.CalledProcessError as e:
-        abort(str(e))
-
-
-@docker.command()
-@pass_config
-@click.pass_context
-def clear_apt_gpgfiles(ctx, config):
-    delete_gpg_files()
-    click.secho("Deleted GPG files in apt-cacher-ng cache", fg="green")
-
-
-@docker.command(help="ls /var/cache/apt/apt-cacher-ng")
-@click.argument("cache", nargs=-1)
-@pass_config
-@click.pass_context
-def clear_apt_cache(ctx, config, cache):
-    # Check if container is already running
-    result = subprocess.run(
-        ["docker", "ps", "-q", "-f", f"name={APT_CACHER_CONTAINER_NAME}"],
-        capture_output=True,
-        text=True,
-    )
-    containerid = result.stdout.strip()
-    if not containerid:
-        click.secho(f"Container '{APT_CACHER_CONTAINER_NAME}' is not running.")
-        return
-    if not cache:
-        result = subprocess.run(
-            [
-                "docker",
-                "exec",
-                "-it",
-                containerid,
-                "find",
-                "/var/cache/apt-cacher-ng/",
-                "-maxdepth",
-                "1",
-                "-type",
-                "d",
-                "-printf",
-                "%f\n",
-            ],
-            capture_output=True,
-            text=True,
-        )
-        options = []
-        for line in result.stdout.splitlines()[1:]:
-            if line.strip() in ["_xstore", "var"]:
-                continue
-            options.append(line)
-        import inquirer
-
-        todelete = inquirer.prompt(
-            [
-                inquirer.List(
-                    "filename", "Choose cache to delete", choices=options
-                )
-            ]
-        )["filename"]
-        if not todelete:
-            abort("No cache selected, aborting.")
-        todelete = [todelete]
-
-    else:
-        todelete = cache
-    for cache in todelete:
-        subprocess.run(
-            [
-                "docker",
-                "exec",
-                "-it",
-                containerid,
-                "rm",
-                "-Rf",
-                "/var/cache/apt-cacher-ng/{cache}",
-            ],
-            capture_output=True,
-            text=True,
-        )
-        click.secho(
-            f"Removed cache {cache} from {APT_CACHER_CONTAINER_NAME}",
-            fg="green",
-        )
-    click.secho("Stopping apt proxy...", fg="green")
-    subprocess.run(["docker", "kill", containerid])
-
-
 @docker.command()
 @click.argument("machines", nargs=-1)
 @click.option("--no-cache", is_flag=True)
@@ -510,12 +289,34 @@ def clear_apt_cache(ctx, config, cache):
 @click.option("--push", is_flag=True)
 @click.option("-p", "--plain", is_flag=True)
 @click.option("-s", "--include-source", is_flag=True)
+@click.option(
+    "--platform",
+    type=click.Choice(["linux/amd64", "linux/arm64"], case_sensitive=False),
+    default=None,
+    help="Build for a specific platform",
+)
 @pass_config
 @click.pass_context
-def build(ctx, config, machines, pull, no_cache, push, plain, include_source):
+def build(
+    ctx,
+    config,
+    machines,
+    pull,
+    no_cache,
+    push,
+    plain,
+    include_source,
+    platform,
+):
     import yaml
+    from .lib_aptcacher import start_apt_cacher
 
-    start_apt_cacher()
+    from .myconfigparser import MyConfigParser
+
+    settings = MyConfigParser(config.files["settings"])
+
+    if settings.get("RUN_APT_CACHER") in ["1", ""]:
+        start_apt_cacher(config)
 
     ensure_project_name(config)
     if plain:
@@ -529,7 +330,16 @@ def build(ctx, config, machines, pull, no_cache, push, plain, include_source):
             if not compose["services"][service].get("build", {}).get("imgage"):
                 machines.append(service)
 
-    lib_build(ctx, config, machines, pull, no_cache, push, include_source)
+    lib_build(
+        ctx,
+        config,
+        machines,
+        pull,
+        no_cache,
+        push,
+        include_source,
+        platform=platform,
+    )
 
 
 @docker.command()
@@ -787,7 +597,7 @@ def docker_sizes(context, config):
     from .tools import __dc_out
     from tabulate import tabulate
 
-    output = __dc_out(config, ["config"]).decode("utf-8")
+    output = __dc_out(config, ["config"])
     # docker-compose config | grep "image:" | awk '{print $2}'
     # docker images --format "{{.Repository}}:{{.Tag}} Size: {{.Size}}"
     import yaml
