@@ -15,7 +15,8 @@ def lang(config):
 @lang.command(name="export")
 @click.argument("lang", required=True)
 @click.argument("modules", nargs=-1, required=True)
-def export_i18n(lang, modules):
+@pass_config
+def export_i18n(config, lang, modules):
     modules = ",".join(modules)
     __dcexec(config, ["odoo", "/odoolib/export_i18n.py", lang, modules])
 
@@ -40,5 +41,6 @@ def get_all_langs(config):
 @lang.command(name="import")
 @click.argument("lang", required=False)
 @click.argument("po-file-path", required=True)
-def lang_import_i18n(lang, po_file_path):
+@pass_config
+def lang_import_i18n(config, lang, po_file_path):
     __dcrun(config, ["odoo", "/odoolib/import_i18n.py", lang, po_file_path])
